TransH
======

.. currentmodule:: pykeen.models

.. autoclass:: TransH
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransH.hpo_default
      ~TransH.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransH.post_parameter_update
      ~TransH.regularize_if_necessary
      ~TransH.score_h
      ~TransH.score_hrt
      ~TransH.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: post_parameter_update
   .. automethod:: regularize_if_necessary
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
